@@ -71,8 +71,13 @@ class Context:
         Implements the kas build context.
     """
     def __init__(self, args):
-        self.__kas_work_dir = os.environ.get('KAS_WORK_DIR', os.getcwd())
-        self.__kas_repo_ref_dir = os.environ.get('KAS_REPO_REF_DIR', None)
+        work_dir = os.environ.get('KAS_WORK_DIR', os.getcwd())
+        self.__kas_work_dir = os.path.abspath(work_dir)
+        build_dir = os.environ.get('KAS_BUILD_DIR',
+                                   os.path.join(self.__kas_work_dir, 'build'))
+        self.__kas_build_dir = os.path.abspath(build_dir)
+        ref_dir = os.environ.get('KAS_REPO_REF_DIR', None)
+        self.__kas_repo_ref_dir = os.path.abspath(ref_dir) if ref_dir else None
         self.setup_initial_environ()
         self.config = None
         self.args = args
@@ -110,7 +115,7 @@ class Context:
         """
             The path to the build directory
         """
-        return os.path.join(self.__kas_work_dir, 'build')
+        return self.__kas_build_dir
 
     @property
     def kas_work_dir(self):
