@@ -259,7 +259,11 @@ def get_build_environ(build_system):
 
     env.update(conf_env)
 
-    if 'BB_ENV_EXTRAWHITE' in env:
+    if 'BB_ENV_PASSTHROUGH_ADDITIONS' in env:
+        passthrough_additions = env['BB_ENV_PASSTHROUGH_ADDITIONS'] + ' ' + \
+            ' '.join(env_vars)
+        env.update({'BB_ENV_PASSTHROUGH_ADDITIONS': passthrough_additions})
+    elif 'BB_ENV_EXTRAWHITE' in env:
         extra_white = env['BB_ENV_EXTRAWHITE'] + ' ' + ' '.join(env_vars)
         env.update({'BB_ENV_EXTRAWHITE': extra_white})
 
@@ -374,9 +378,8 @@ def ssh_no_host_key_check():
 
 def setup_parser_common_args(parser):
     parser.add_argument('config',
-                        help='Config file, using .config.yaml if none is '
-                        'specified and using the current directory as '
-                        'repository anchor',
+                        help='Config file, using .config.yaml in KAS_WORK_DIR '
+                        'if none is specified',
                         nargs='?')
     parser.add_argument('--skip',
                         help='Skip build steps',
@@ -387,3 +390,30 @@ def setup_parser_common_args(parser):
     parser.add_argument('--update', action='store_true',
                         help='Pull new upstream changes to the desired '
                         'refspec even if it is already checked out locally')
+
+
+def setup_parser_preserve_env_arg(parser):
+    parser.add_argument('-E', '--preserve-env',
+                        help='Keep current user enviornment block',
+                        action='store_true')
+
+
+def run_handle_preserve_env_arg(ctx, os, args, SetupHome):
+    if args.preserve_env:
+        # Warn if there's any settings that setup_home would apply
+        # but are now ignored
+        for var in SetupHome.ENV_VARS:
+            if var in os.environ:
+                logging.warning('Environment variable "%s" ignored '
+                                'because user environment is being used',
+                                var)
+
+        if not os.isatty(sys.stdout.fileno()):
+            logging.error("Error: --preserve-env can only be "
+                          "run from a tty")
+            sys.exit(1)
+
+        ctx.environ = os.environ.copy()
+
+        logging.warning("Preserving the current environment block may "
+                        "have unintended side effects on the build.")
