@@ -38,12 +38,15 @@
 """
 
 import logging
+import os
 import subprocess
 import sys
 from kas.context import create_global_context
 from kas.config import Config
-from kas.libcmds import Macro, Command
+from kas.libcmds import Macro, Command, SetupHome
 from kas.libkas import setup_parser_common_args
+from kas.libkas import setup_parser_preserve_env_arg
+from kas.libkas import run_handle_preserve_env_arg
 
 __license__ = 'MIT'
 __copyright__ = 'Copyright (c) Siemens AG, 2017-2018'
@@ -64,6 +67,7 @@ class Shell:
         """
 
         setup_parser_common_args(parser)
+        setup_parser_preserve_env_arg(parser)
         parser.add_argument('-k', '--keep-config-unchanged',
                             help='Skip steps that change the configuration',
                             action='store_true')
@@ -79,6 +83,8 @@ class Shell:
         ctx = create_global_context(args)
         ctx.config = Config(ctx, args.config)
 
+        run_handle_preserve_env_arg(ctx, os, args, SetupHome)
+
         if args.keep_config_unchanged:
             # Skip the tasks which would change the config of the build
             # environment
