@@ -111,6 +111,10 @@ class Repo:
         typ = repo_config.get('type', 'git')
         refspec = repo_config.get('refspec',
                                   repo_defaults.get('refspec', None))
+        if refspec is None and url is not None:
+            logging.error('No refspec specified for repository "%s". This is '
+                          'only allowed for local repositories.', name)
+            sys.exit(1)
         path = repo_config.get('path', None)
         disable_operations = False
 
@@ -358,9 +362,9 @@ class GitRepo(RepoImpl):
         return ['git', 'cat-file', '-t', self.remove_ref_prefix(self.refspec)]
 
     def fetch_cmd(self):
-        cmd = ['git', 'fetch']
+        cmd = ['git', 'fetch', '-q']
         if self.refspec.startswith('refs/'):
-            cmd.extend(['--quiet', 'origin',
+            cmd.extend(['origin',
                         '+' + self.refspec
                         + ':refs/remotes/origin/'
                         + self.remove_ref_prefix(self.refspec)])
@@ -389,7 +393,7 @@ class GitRepo(RepoImpl):
                 format(refspec=self.remove_ref_prefix(self.refspec))]
 
     def apply_patches_file_cmd(self, path):
-        return ['git', 'apply', path]
+        return ['git', 'apply', '--whitespace=nowarn', path]
 
     def set_remote_url_cmd(self):
         return ['git', 'remote', 'set-url', 'origin', self.effective_url]
